pub struct Link {
pub resource: String,
pub verb: Verb,
pub title: Option<String>,
pub _type: Option<String>,
}Expand description
Link : A link to resources related to a listing restriction.
Fields
resource: StringThe URI of the related resource.
verb: VerbThe HTTP verb used to interact with the related resource.
title: Option<String>The title of the related resource.
_type: Option<String>The media type of the related resource.
Implementations